@@ -1,11 +1,8 @@
 package Math::Polygon::Tree;
-{
-  $Math::Polygon::Tree::VERSION = '0.07';
-}
-
+$Math::Polygon::Tree::VERSION = '0.08';
 # ABSTRACT: fast check if point is inside polygon
 
-# $Id: Tree.pm 27 2014-09-03 08:08:31Z xliosha@gmail.com $
+# $Id$
 
 
 use 5.010;
@@ -249,7 +246,11 @@ sub contains {
     # check bbox
     my ($px, $py) = @$point;
     my ($xmin, $ymin, $xmax, $ymax) = @{ $self->{bbox} };
-    return 0  if $px < $xmin  ||  $px > $xmax  ||  $py < $ymin  ||  $py > $ymax;
+    return 0
+        if $px < $xmin-$POLYGON_BORDER_WIDTH
+        || $px > $xmax+$POLYGON_BORDER_WIDTH
+        || $py < $ymin-$POLYGON_BORDER_WIDTH
+        || $py > $ymax+$POLYGON_BORDER_WIDTH;
 
     # leaf
     if ( exists $self->{poly} ) {
@@ -424,6 +425,8 @@ sub polygon_contains_point {
     for my $i ( 1 .. scalar @$contour ) { 
         ($nx, $ny) =  @{ $contour->[ $i % scalar @$contour ] };
 
+        return -1  if abs($y-$py) < $POLYGON_BORDER_WIDTH && abs($x-$px) < $POLYGON_BORDER_WIDTH;
+
         return -1
             if  abs($y-$py) < $POLYGON_BORDER_WIDTH  &&  abs($py-$ny) < $POLYGON_BORDER_WIDTH
                 && ( $x >= $px  ||  $x >= $nx )
@@ -462,7 +465,7 @@ Math::Polygon::Tree - fast check if point is inside polygon
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -593,7 +596,7 @@ liosha <liosha@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by liosha.
+This software is copyright (c) 2015 by liosha.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
